Projectivize

Trait Projectivize 

pub trait Projectivize {
    // Required method
    fn projectivize(&self, sentence: &mut Sentence) -> Result<(), Error>;
}
Graph projectivizer.

Required Methods

fn projectivize(&self, sentence: &mut Sentence) -> Result<(), Error>

Projectivize a graph

This method rewrites a non-projective graph into a projective graph. Depending on the projectivizer, this may add additional information to the dependency labels to undo the projectivization later.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors